# -*- encoding: utf-8 -*-

##############################################################################
#
# Copyright (c) 2010-2012 E.Samyn - esamyn@gmail.com
# Author: E.Samyn
# www.erp-236.com
#
# This file is part of the project_work_er module (Easy Time Tracking)
#
# WARNING: This program as such is intended to be used by professional
# programmers who take the whole responsability of assessing all potential
# consequences resulting from its eventual inadequacies and bugs
# End users who are looking for a ready-to-use solution with commercial
# garantees and support are strongly adviced to contract a Free Software
# Service Company
#
# This program is Free Software; you can redistribute it and/or
# modify it under the terms of the GNU Affero General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program; 
# If not, see <http://www.gnu.org/licenses/> or  write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
##############################################################################
from datetime import datetime, timedelta
import time

from osv import fields, osv

class project_work(osv.osv):
    _name = "project.task.work"
    _description = "Project Task Work extension"
    _inherit = "project.task.work"
    _columns = {
        'start_date_time': fields.datetime('Start'),
        'working_state' : fields.selection([('stopped','Stopped'),
                                            ('started','Started'),], 'Working state'),
    }
    _defaults={
          'working_state': lambda *a: 'stopped',
    }

    # Method to set work starting time
    def start_work(self, cr, uid, ids, context=None):
        if self.browse(cr, uid, ids, context=context)[0].working_state == 'stopped':
            self.write(cr, uid, ids, {'working_state':'started','start_date_time':time.strftime('%Y-%m-%d %H:%M:%S')}, context=context)
        return True

    # Method to calculate and record work duration
    def stop_work(self, cr, uid, ids, context=None):
        work_line = self.browse(cr, uid, ids, context=context)[0]
        if work_line.working_state == 'started':
            new_work_qty = work_line.hours
            start_time = time.strptime(work_line.start_date_time,'%Y-%m-%d %H:%M:%S')
            stop_time = time.strptime(time.strftime('%Y-%m-%d %H:%M:%S'),'%Y-%m-%d %H:%M:%S')
            # Work recorded only for one day => start and stop date must be the same
            if start_time.tm_year==stop_time.tm_year and start_time.tm_mon==stop_time.tm_mon and start_time.tm_mday==stop_time.tm_mday:
                delta_hours = stop_time.tm_hour-start_time.tm_hour
                delta_min = float(stop_time.tm_min-start_time.tm_min)/60
                new_work_qty = work_line.hours + delta_hours + round(delta_min, 2)
            self.write(cr, uid, ids, {'working_state':'stopped','hours':new_work_qty}, context=context)
        return True
        
project_work()
